summaryrefslogtreecommitdiff
path: root/c/test_c.py
diff options
context:
space:
mode:
Diffstat (limited to 'c/test_c.py')
-rw-r--r--c/test_c.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/c/test_c.py b/c/test_c.py
index 5fd670b..79063dc 100644
--- a/c/test_c.py
+++ b/c/test_c.py
@@ -1529,7 +1529,7 @@ def test_callback_return_type():
def test_a_lot_of_callbacks():
BIGNUM = 10000
- if 'PY_DOT_PY' in globals(): BIGNUM = 100 # tests on py.py
+ if 'PY_DOT_PY' in globals(): BIGNUM = 100 # tests on pypy
#
BInt = new_primitive_type("int")
BFunc = new_function_type((BInt,), BInt, False)
@@ -3960,7 +3960,7 @@ def test_from_buffer_types():
#
p2 = from_buffer(BIntP, bytestring) # int *
assert p2 == p1 or 'PY_DOT_PY' in globals()
# note: on py.py ^^^, bytearray buffers are not emulated well enough
assert typeof(p2) is BIntP
assert p2[0] == lst[0]
assert p2[1] == lst[1]
@@ -3960,7 +3960,7 @@ def test_from_buffer_types():
p2 = from_buffer(BIntP, bytestring) # int *
assert p2 == p1 or 'PY_DOT_PY' in globals()
- # note: on py.py ^^^, bytearray buffers are not emulated well enough
+ # note: on pypy ^^^, bytearray buffers are not emulated well enough
assert typeof(p2) is BIntP
assert p2[0] == lst[0]